==> haskell-brick-0.46-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.46
id: brick-0.46-4Ay4C9tTNyKGzji7cJUyhI
key: brick-0.46-4Ay4C9tTNyKGzji7cJUyhI
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: dfad533e876b36c88f3f525c7f7c163b
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.46
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.46
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.46
hs-libraries: HSbrick-0.46-4Ay4C9tTNyKGzji7cJUyhI
depends:
    base-4.12.0.0 config-ini-0.2.4.0-7OKhcDUqejM5gjozU4Fis2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.2-IoLhYnvwkJk3U8mo1aTgQA deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.6-Cxrf3wOfeJW535RKj0Gaep
    filepath-1.4.2.1 microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-mtl-0.1.11.1-CE5sGqQZkL9EXFDjpbpByt
    microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.25.1-cF9F280wXuLrx8PnDelMi
    word-wrap-0.4.1-EMooAe4gP3E79QWPstrywc
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.46-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.46
id: brick-0.46-CdLsDFRbE0UL0DaJeIkvHf
key: brick-0.46-CdLsDFRbE0UL0DaJeIkvHf
license: BSD-3-Clause
copyright: (c) Jonathan Daugherty 2015-2018
maintainer: Jonathan Daugherty <cygnus@foobox.com>
author: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
abi: 1778699aa504f191133dbab6bcf6f646
exposed: True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Markup Brick.Themes Brick.Types
    Brick.Util Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.IMap Data.Text.Markup
hidden-modules: Brick.Types.Common Brick.Types.TH
                Brick.Types.Internal Brick.Widgets.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.46
library-dirs: /usr/lib/ghc-8.6.5/site-local/brick-0.46
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/brick-0.46
hs-libraries: HSbrick-0.46-CdLsDFRbE0UL0DaJeIkvHf
depends:
    base-4.12.0.0 config-ini-0.2.4.0-7OKhcDUqejM5gjozU4Fis2
    containers-0.6.0.1 contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    data-clist-0.1.2.2-IoLhYnvwkJk3U8mo1aTgQA deepseq-1.4.4.0
    directory-1.3.3.0 dlist-0.8.0.6-Cxrf3wOfeJW535RKj0Gaep
    filepath-1.4.2.1 microlens-0.4.11.1-5dh821ORebgAorhvJor7TN
    microlens-mtl-0.2.0.1-E4YQOt1SovZ6XqAZ7j7hTE
    microlens-th-0.4.3.1-AUW9LaqhPnN9WhzH0kkXqs stm-2.5.0.0
    template-haskell-2.14.0.0 text-1.2.3.1
    text-zipper-0.10.1-JkqGgN6zbRU5SddSjNsQLm transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vty-5.25.1-Gwpkn0eD7RDB852iBG2MsU
    word-wrap-0.4.1-EMooAe4gP3E79QWPstrywc
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
